@@ -1,20 +1,8 @@
 # -*- coding: utf-8 -*-
 from plone import api
-from plone.app.contenttypes.browser.folder import FolderView
 from Products.Five.browser import BrowserView
 
 
-class ChannelFolderView(FolderView):
-
-    def getState(self, message):
-        stateDict = {
-            'draft': 'bozza',
-            'review': 'in attesa di invio',
-            'sent': 'inviato'
-        }
-        return stateDict[api.content.get_state(obj=message.getObject())]
-
-
 class ChannelView(BrowserView):
 
     def getState(self, message):
